﻿Imports System.ComponentModel.Composition

Namespace Utils.Demo.ContosoSales.MVVM.Model

    <Export(GetType(IDataService))>
    Public Class DummyDataService
        Implements IDataService
        ''' <summary>
        ''' Internal list of customers.
        ''' </summary>
        Private Shared customers As List(Of Customer)

        ''' <summary>
        ''' Internal list of employees.
        ''' </summary>
        Private Shared employees As List(Of Employee)

        Public Sub New()
            EnsureCustomers()
            EnsureEmployees()
        End Sub

        ''' <summary>
        ''' Ensure the employees list.
        ''' </summary>
        Private Sub EnsureEmployees()
            If employees Is Nothing Then
                employees = New List(Of Employee)()
                employees.Add(New Employee() With {.Age = 23, .Firstname = "Sandrino",
                                                   .IsManagement = False, .IsSales = True,
                                                   .Lastname = "Di Mattia"})
                employees.Add(New Employee() With {.Age = 23, .Firstname = "User 1",
                                                   .IsManagement = False, .IsSales = True,
                                                   .Lastname = "User 1"})
                employees.Add(New Employee() With {.Age = 39, .Firstname = "User 2",
                                                   .IsManagement = True, .IsSales = False,
                                                   .Lastname = "User 2"})
            End If
        End Sub

        ''' <summary>
        ''' Ensure the customers list.
        ''' </summary>
        Private Sub EnsureCustomers()
            If customers Is Nothing Then
                customers = New List(Of Customer)()
                customers.Add(New Customer() With {.Id = 0, .City = "City 0",
                                                   .Company = "Company 0",
                                                   .CustomerSince = 1980,
                                                   .Email = "info@company0.com",
                                                   .Sold = 8000, .Street = "My Street 0"})
                customers.Add(New Customer() With {.Id = 1, .City = "City 1",
                                                   .Company = "Company 1",
                                                   .CustomerSince = 2000,
                                                   .Email = "info@company1.com",
                                                   .Sold = 1266388, .Street = "My Street 1"})
                customers.Add(New Customer() With {.Id = 2, .City = "City 2",
                                                   .Company = "Company 2",
                                                   .CustomerSince = 2002,
                                                   .Email = "info@company2.com",
                                                   .Sold = 9983, .Street = "My Street 2"})
                customers.Add(New Customer() With {.Id = 3, .City = "City 3",
                                                   .Company = "Company 3",
                                                   .CustomerSince = 2005,
                                                   .Email = "info@company3.com",
                                                   .Sold = 8839, .Street = "My Street 3"})
                customers.Add(New Customer() With {.Id = 4, .City = "City 4",
                                                   .Company = "Company 4",
                                                   .CustomerSince = 2008,
                                                   .Email = "info@company4.com",
                                                   .Sold = 2049, .Street = "My Street 4"})
            End If
        End Sub

        ''' <summary>
        ''' Get the customers list.
        ''' </summary>
        ''' <returns></returns>
        Public Function GetCustomers() As List(Of Customer) Implements IDataService.GetCustomers
            Return customers
        End Function

        ''' <summary>
        ''' Find a customer.
        ''' </summary>
        ''' <param name="id"></param>
        ''' <returns></returns>
        Public Function GetCustomerById(ByVal id As Integer) As Customer Implements IDataService.GetCustomerById
            Return customers.FirstOrDefault(Function(o) o.Id = id)
        End Function

        ''' <summary>
        ''' Get the employees list.
        ''' </summary>
        ''' <returns></returns>
        Public Function GetEmployees() As List(Of Employee) Implements IDataService.GetEmployees
            Return employees
        End Function

        ''' <summary>
        ''' Find an employee.
        ''' </summary>
        ''' <param name="lastname"></param>
        ''' <returns></returns>
        Public Function GetEmployeeByLastname(ByVal lastname As String) As Employee Implements IDataService.GetEmployeeByLastname
            Return employees.FirstOrDefault(Function(o) o.Lastname.Replace(" ", "") = lastname)
        End Function
    End Class
End Namespace
