﻿Imports System.Windows.Input
Imports System.ComponentModel.Composition
Imports Utils.Silverlight.MVVM
Imports Utils.Silverlight.MVVM.Navigation
Imports Utils.Demo.ContosoSales.MVVM.Model
Imports GalaSoft.MvvmLight.Command

Namespace Utils.Demo.ContosoSales.MVVM.ViewModels
    <ViewModelExport(GetType(ICustomerDetailViewModel), "Customer/{id}")>
 Public Class CustomerDetailViewModel
        Inherits ContosoViewModelBase
        Implements ICustomerDetailViewModel
        ''' <summary>
        ''' The data service.
        ''' </summary>
        ''' <value></value>

        <Import()>
        Public Property DataService() As IDataService Implements ICustomerDetailViewModel.DataService

        ''' <summary>
        ''' Cancel command.
        ''' </summary>
        Public Property CancelCommand() As ICommand

        ''' <summary>
        ''' Close event mapped to the View.
        ''' </summary>
        Public Event CloseView As EventHandler Implements ICustomerDetailViewModel.CloseView

        ''' <summary>
        ''' Customer field.
        ''' </summary>

        Private _customer As Customer

        ''' <summary>
        ''' Customer.
        ''' </summary>
        Public Property Customer() As Customer Implements ICustomerDetailViewModel.Customer
            Get
                Return _customer
            End Get
            Set(ByVal value As Customer)
                _customer = value
                RaisePropertyChanged("Customer")
            End Set
        End Property

        ''' <summary>
        ''' Raise the close event so we can close the view.
        ''' </summary>
        Public Sub RaiseClose()
            RaiseEvent CloseView(Me, Nothing)
        End Sub

        Public Sub New()
            CancelCommand = New RelayCommand(AddressOf RaiseClose)
        End Sub

        ''' <summary>
        ''' Get the customer's id after navigating and load the customer.
        ''' </summary>
        ''' <param name="args"></param>
        Public Overrides Sub OnNavigated(ByVal args As NavigationArguments)
            Dim id = args.GetInt("Id")
            If id.HasValue Then
                Customer = DataService.GetCustomerById(id.Value)
            End If
        End Sub

        ''' <summary>
        ''' Provide the customer's company name as title.
        ''' </summary>
        ''' <returns></returns>
        Public Overrides Function GetViewTitle() As String
            If Customer IsNot Nothing Then
                Return Customer.Company
            Else
                Return "Customer Detail"
            End If
        End Function
    End Class
End Namespace
