﻿Imports System.Windows.Input
Imports System.ComponentModel.Composition

Imports GalaSoft.MvvmLight.Command

Imports Utils.Silverlight.MVVM
Imports Utils.Demo.ContosoSales.MVVM.Model

Namespace Utils.Demo.ContosoSales.MVVM.ViewModels

    <ViewModelExport(GetType(ICustomersViewModel), "Customers")>
    Public Class CustomersViewModel
        Inherits ContosoViewModelBase
        Implements ICustomersViewModel

#Region "Properties & Fields"
        ''' <summary>
        ''' Service giving access to the data.
        ''' </summary>

        <Import()>
        Public Property DataService() As IDataService Implements ICustomersViewModel.DataService

        ''' <summary>
        ''' Open customer command.
        ''' </summary>
        Public Property OpenCustomerCommand() As ICommand Implements ICustomersViewModel.OpenCustomerCommand

        ''' <summary>
        ''' Help command.
        ''' </summary>
        Public Property HelpCommand() As ICommand Implements ICustomersViewModel.HelpCommand

        ''' <summary>
        ''' Customer field.
        ''' </summary>
        Private _selectedCustomer As Customer

        ''' <summary>
        ''' Current customer.
        ''' </summary>
        Public Property SelectedCustomer() As Customer Implements ICustomersViewModel.SelectedCustomer
            Get
                Return _selectedCustomer
            End Get
            Set(ByVal value As Customer)
                _selectedCustomer = value
                RaisePropertyChanged("SelectedCustomer")

                ' Refresh the command.
                Dim openCustomerRelay = TryCast(OpenCustomerCommand, RelayCommand)
                openCustomerRelay.RaiseCanExecuteChanged()
            End Set
        End Property

        ''' <summary>
        ''' Internal customers field.
        ''' </summary>
        Private _customers As List(Of Customer)

        ''' <summary>
        ''' List of customers.
        ''' </summary>
        Public Property Customers() As List(Of Customer) Implements ICustomersViewModel.Customers
            Get
                Return _customers
            End Get
            Set(ByVal value As List(Of Customer))
                _customers = value
                RaisePropertyChanged("Customers")
            End Set
        End Property
#End Region

        ''' <summary>
        ''' Initialize the ViewModel to create the commands.
        ''' </summary>
        Public Sub New()
            HelpCommand = New RelayCommand(AddressOf OnHelp)
            OpenCustomerCommand = New RelayCommand(AddressOf OnOpenCustomer, AddressOf CanOpenCustomer)
        End Sub

        ''' <summary>
        ''' Can the customer be opened.
        ''' </summary>
        ''' <returns></returns>
        Private Function CanOpenCustomer() As Boolean
            Return SelectedCustomer IsNot Nothing
        End Function

        ''' <summary>
        ''' Open the selected customer.
        ''' </summary>
        Private Sub OnOpenCustomer()
            NavigationService.Navigate("Customer/{0}", SelectedCustomer.Id)
        End Sub

        ''' <summary>
        ''' Navigate for help.
        ''' </summary>
        Private Sub OnHelp()
            NavigationService.Navigate("Help/{0}", "Customers")
        End Sub

        ''' <summary>
        ''' Once the ViewModel is loaded the DataService will be imported.
        ''' After that get the cutomer list.
        ''' </summary>
        Public Overrides Sub OnLoaded()
            Customers = DataService.GetCustomers()
        End Sub

        Public Overrides Function GetViewTitle() As String
            Return "Customers"
        End Function
    End Class
End Namespace
