﻿Imports System.Windows.Input
Imports System.Windows.Browser
Imports System.Windows.Controls

Imports GalaSoft.MvvmLight.Command

Imports Utils.Silverlight.MVVM
Imports Utils.Silverlight.MVVM.Navigation

Namespace Utils.Demo.ContosoSales.MVVM.ViewModels
    <ViewModelExport(GetType(IHelpViewModel), "Help/{Topic}")>
    Public Class HelpViewModel
        Inherits ContosoViewModelBase
        Implements IHelpViewModel
        ''' <summary>
        ''' Help text to show.
        ''' </summary>
        Public Property HelpText() As String Implements IHelpViewModel.HelpText

        ''' <summary>
        ''' What is the user searching for.
        ''' </summary>
        Public Property SearchText() As String Implements IHelpViewModel.SearchText
          
        ''' <summary>
        ''' Close event.
        ''' </summary>
        Public Event CloseView As EventHandler Implements IHelpViewModel.CloseView

        ''' <summary>
        ''' Close.
        ''' </summary>
        Public Property CloseCommand() As ICommand Implements IHelpViewModel.CloseCommand

        ''' <summary>
        ''' Search.
        ''' </summary>
        Public Property SearchCommand() As ICommand Implements IHelpViewModel.SearchCommand

        ''' <summary>
        ''' Initialize the ViewModel.
        ''' </summary>
        Public Sub New()
            HelpText = "Enter a query and press Search." & vbCrLf & "This will launch Bing.com and you might get an answer to your question there."
            CloseCommand = New RelayCommand(AddressOf OnClose)
            SearchCommand = New RelayCommand(AddressOf OnSearch)
        End Sub

        ''' <summary>
        ''' When navigated, get the topic and enter this in the Search box.
        ''' </summary>
        ''' <param name="args"></param>
        Public Overrides Sub OnNavigated(ByVal args As NavigationArguments)
            If args.ContainsKey("Topic") Then
                SearchText = TryCast(args("Topic"), String)
                RaisePropertyChanged("SearchText")
            End If
        End Sub

        ''' <summary>
        ''' Launch the search.
        ''' </summary>
        Private Sub OnSearch()
            ' Format the search url.
            Dim searchUrl = "http://www.bing.com/search?q=Contoso+{0}"
            searchUrl = String.Format(searchUrl, SearchText)

            ' Open the new browser window.
            HtmlPage.PopupWindow(New Uri(searchUrl), "", New HtmlPopupWindowOptions())
        End Sub

        ''' <summary>
        ''' Close the ViewModel.
        ''' </summary>
        Public Sub OnClose()
            RaiseEvent CloseView(Me, Nothing)
        End Sub

        ''' <summary>
        ''' Get the title based on the search text.
        ''' </summary>
        ''' <returns></returns>
        Public Overrides Function GetViewTitle() As String
            If SearchText Is Nothing Then
                Return "Help"
            Else
                Return "Help: " & SearchText
            End If
        End Function
    End Class
End Namespace
