﻿Imports System.Windows.Input
Imports System.ComponentModel.Composition

Imports GalaSoft.MvvmLight
Imports GalaSoft.MvvmLight.Command

Imports Utils.Silverlight.MVVM
Imports Utils.Demo.ContosoSales.MVVM.Model

Namespace Utils.Demo.ContosoSales.MVVM.ViewModels
    <ViewModelExport(GetType(ISalesTeamViewModel), "SalesTeam")>
 Public Class SalesTeamViewModel
        Inherits ContosoViewModelBase
        Implements ISalesTeamViewModel

        <Import()>
        Public Property DataService() As IDataService Implements ISalesTeamViewModel.DataService

        ''' <summary>
        ''' Open employee command.
        ''' </summary>
        Public Property OpenEmployeeCommand() As ICommand Implements ISalesTeamViewModel.OpenEmployeeCommand
         
        ''' <summary>
        ''' Navigate to help command.
        ''' </summary>
        Public Property HelpCommand() As ICommand Implements ISalesTeamViewModel.HelpCommand

        ''' <summary>
        ''' Selected employee field.
        ''' </summary>

        Private _selectedEmployee As Employee

        ''' <summary>
        ''' Current employee.
        ''' </summary>
        Public Property SelectedEmployee() As Employee Implements ISalesTeamViewModel.SelectedEmployee
            Get
                Return _selectedEmployee
            End Get
            Set(ByVal value As Employee)
                _selectedEmployee = value
                RaisePropertyChanged("SelectedEmployee")

                ' Refresh the command.
                Dim openCustomerRelay = TryCast(OpenEmployeeCommand, RelayCommand)
                openCustomerRelay.RaiseCanExecuteChanged()
            End Set
        End Property

        ''' <summary>
        ''' Employees field.
        ''' </summary>

        Private _employees As List(Of Employee)

        ''' <summary>
        ''' The employees list.
        ''' </summary>
        Public Property Employees() As List(Of Employee) Implements ISalesTeamViewModel.Employees
            Get
                Return _employees
            End Get
            Set(ByVal value As List(Of Employee))
                _employees = value
                RaisePropertyChanged("Employees")
            End Set
        End Property

        ''' <summary>
        ''' Initialize the commands.
        ''' </summary>
        Public Sub New()
            HelpCommand = New RelayCommand(AddressOf OnHelp)
            OpenEmployeeCommand = New RelayCommand(AddressOf OnOpenEmployee, AddressOf CanOpenCustomer)
        End Sub

        ''' <summary>
        ''' Can an employee be opened.
        ''' </summary>
        ''' <returns></returns>
        Private Function CanOpenCustomer() As Boolean
            Return SelectedEmployee IsNot Nothing
        End Function

        ''' <summary>
        ''' Open a customer.
        ''' </summary>
        Private Sub OnOpenEmployee()
            NavigationService.Navigate("Employee/{0}", SelectedEmployee.Lastname.Replace(" ", ""))
        End Sub

        ''' <summary>
        ''' Navigate to Help.
        ''' </summary>
        Private Sub OnHelp()
            NavigationService.Navigate("Help/{0}", "Sales Team")
        End Sub

        ''' <summary>
        ''' Load the employees once the DataService has been imported.
        ''' This happens after loading the ViewModel.
        ''' </summary>
        Public Overrides Sub OnLoaded()
            Employees = DataService.GetEmployees().Where(Function(o) o.IsSales).ToList()
        End Sub

        ''' <summary>
        ''' Custom title for the view.
        ''' </summary>
        ''' <returns></returns>
        Public Overrides Function GetViewTitle() As String
            Return "Sales Team"
        End Function
    End Class
End Namespace
