﻿Imports System.Reflection
Imports System.ComponentModel.Composition

Imports Utils.Silverlight.MVVM.Navigation

Namespace Utils.Silverlight.MVVM
    <MetadataAttribute(), AttributeUsage(AttributeTargets.Class, AllowMultiple:=False)>
 Public Class ViewModelExportAttribute
        Inherits ExportAttribute
        Implements IViewModelMetadata
        ''' <summary>
        ''' The actual interface of the ViewModel.
        ''' This type will be used to match a View to a ViewModel.
        ''' </summary>
        ''' <value></value>
        Private _ViewModelContract As Type
        Public ReadOnly Property ViewModelContract() As Type Implements IViewModelMetadata.ViewModelContract
            Get
                Return _ViewModelContract
            End Get
        End Property
        Public Property Set_ViewModelContract As Type
            Set(ByVal value As Type)
                _ViewModelContract = value
            End Set
            Get
                Return _ViewModelContract
            End Get
        End Property

        ''' <summary>
        ''' Specify to which navigation key this ViewModel should be mapped.
        ''' Eg: 'Customers', or 'Customer/1'
        ''' </summary>
        Private _NavigationPath As String
        Public ReadOnly Property NavigationPath() As String Implements IViewModelMetadata.NavigationPath
            Get
                Return _NavigationPath
            End Get
        End Property
        Public Property Set_NavigationPath() As String
            Get
                Return _NavigationPath
            End Get
            Set(ByVal value As String)
                _NavigationPath = value
            End Set
        End Property

        ''' <summary>
        ''' This is the actual navigation key. 
        ''' 'Customer/1' would have as key: 'Customer'.
        ''' </summary>
        Private _Key As String
        Public ReadOnly Property Key() As String Implements IViewModelMetadata.Key
            Get
                Return _Key
            End Get
        End Property
        Public Property Set_Key() As String
            Get
                Return _Key
            End Get
            Set(ByVal value As String)
                _Key = value
            End Set
        End Property

        ''' <summary>
        ''' Initialize the attribute by defining the contract of the ViewModel and the navigation key.
        ''' This viewModelContract should be the same as the one used by the ViewExport attribute.
        ''' </summary>
        ''' <param name="viewModelContract"></param>
        ''' <param name="navigationPath"></param>
        Public Sub New(ByVal viewModelContract As Type, ByVal navigationPath As String)
            MyBase.New(GetType(IViewModel))
            Me.Set_NavigationPath = navigationPath
            Me.Set_ViewModelContract = viewModelContract

            If Me.NavigationPath IsNot Nothing AndAlso Me.NavigationPath.Contains("/") Then
                ' Split the path to get the arguments.
                Dim split = Me.NavigationPath.Split(New Char() {"/"c}, StringSplitOptions.RemoveEmptyEntries)

                ' Get the key.
                Set_Key = split(0)
            Else
                ' No arguments, use the whole key.
                Set_Key = Me.NavigationPath
            End If
        End Sub
    End Class
End Namespace
