﻿Imports System.Threading
Imports System.Windows.Controls

Namespace Utils.Silverlight.MVVM
	''' <summary>
	''' A regular class implementing IAsyncResult.
	''' </summary>
	Friend Class CompositionNavigationAsyncResult
		Implements IAsyncResult
		''' <summary>
		''' The resulting control after the navigation.
        ''' </summary>
        Public Property Result() As Object

        ''' <summary>
        ''' Gets a user-defined object that qualifies or contains information about an asynchronous operation.
        ''' </summary>
        Private _AsyncState As Object
        Public ReadOnly Property AsyncState() As Object Implements IAsyncResult.AsyncState
            Get
                Return _AsyncState
            End Get
        End Property
        Public Property Set_AsyncState() As Object
            Get
                Return _AsyncState
            End Get
            Set(ByVal value As Object)
                _AsyncState = value
            End Set
        End Property

        ''' <summary>
        ''' Gets a System.Threading.WaitHandle that is used to wait for an asynchronous operation to complete.
        ''' </summary>
        Private _AsyncWaitHandle As WaitHandle
        Public ReadOnly Property AsyncWaitHandle() As WaitHandle Implements IAsyncResult.AsyncWaitHandle
            Get
                Return _AsyncWaitHandle
            End Get
        End Property
        Public Property Set_AsyncWaitHandle() As WaitHandle
            Get
                Return _AsyncWaitHandle
            End Get
            Set(ByVal value As WaitHandle)
                _AsyncWaitHandle = value
            End Set
        End Property

		''' <summary>
		''' Gets a value that indicates whether the asynchronous operation completed synchronously.
		''' </summary>
		Public ReadOnly Property CompletedSynchronously() As Boolean Implements IAsyncResult.CompletedSynchronously
			Get
				Return True
			End Get
		End Property

		''' <summary>
		''' Gets a value that indicates whether the asynchronous operation has completed.
		''' </summary>
		Public ReadOnly Property IsCompleted() As Boolean Implements IAsyncResult.IsCompleted
			Get
				Return True
			End Get
		End Property

		''' <summary>
		''' Initialize the navigation result by passing the state and the control).
		''' </summary>
		''' <param name="state"></param>
		''' <param name="result"></param>
		Public Sub New(ByVal state As Object, ByVal control As Control)
			Me.Result = control
            Me._AsyncState = state
            Me._AsyncWaitHandle = New ManualResetEvent(True)
		End Sub
	End Class
End Namespace
