﻿Imports System.Windows.Controls
Imports System.Windows.Navigation
Imports System.Windows.Interactivity

Imports System.ComponentModel
Imports System.ComponentModel.Composition
Imports System.ComponentModel.Composition.Hosting

Imports Utils.Silverlight.MVVM.Navigation

Namespace Utils.Silverlight.MVVM
	Public Class CompositionNavigationBehavior
		Inherits Behavior(Of Frame)
		''' <summary>
		''' Flag to prevent double processing of the behavior.
		''' </summary>
        Private processed As Boolean

		''' <summary>
		''' The container that will allow instance registration.
        ''' </summary>
        <Import()>
        Public Property Container() As CompositionContainer
          

        ''' <summary>
        ''' The loader that will process navigation requests.
        ''' </summary>
        <Import()>
        Public Property Loader() As CompositionNavigationContentLoader
           

		''' <summary>
		''' Initialize the behavior by importing the required objects.
		''' </summary>
		Public Sub New()
			If Not DesignerProperties.IsInDesignTool Then
				CompositionInitializer.SatisfyImports(Me)
			End If
		End Sub

		''' <summary>
		''' Once the frame has been attached, start processing it.
		''' </summary>
		Protected Overrides Sub OnAttached()
			MyBase.OnAttached()

			If Not processed Then
				Me.RegisterNavigationService()
				Me.SetContentLoader()
				processed = True
			End If
		End Sub

		''' <summary>
		''' Create and register a navigation service.
		''' </summary>
		Private Sub RegisterNavigationService()
			' Wrap the frame in a navigation service.
			Dim frame = AssociatedObject
			Dim svc = New Utils.Silverlight.MVVM.Navigation.NavigationService(frame)

			' Register the navigation service as a singleton instance.
			Container.ComposeExportedValue(Of INavigationService)(svc)
		End Sub

		''' <summary>
		''' Set the content loader in the frame.
		''' </summary>
		Private Sub SetContentLoader()
			Dim frame = AssociatedObject
			frame.ContentLoader = Loader
			frame.JournalOwnership = JournalOwnership.Automatic
		End Sub
	End Class
End Namespace
