﻿Namespace Utils.Silverlight.MVVM.Navigation
	Public Module NavigationArgumentExtensions
		''' <summary>
		''' Process the metadata's Path to extract the Arguments.
		''' </summary>
		''' <param name="md">The ViewModel's metadata.</param>
		''' <returns></returns>
        <System.Runtime.CompilerServices.Extension()>
        Public Function GetArguments(ByVal metadata As IViewModelMetadata) As List(Of String)
            ' New list holding the arguments.
            Dim args = New List(Of String)()

            ' Only process if the Path is valid.
            If metadata.NavigationPath IsNot Nothing AndAlso
                metadata.NavigationPath.Contains("/") Then
                ' Split the path to get the arguments.
                Dim split = metadata.NavigationPath.Split(
                    New Char() {"/"c}, StringSplitOptions.RemoveEmptyEntries)

                ' Add each argument.
                For i = 1 To split.Length - 1
                    Dim arg = split(i)
                    arg = arg.Trim("{"c, "}"c)
                    args.Add(arg)
                Next i
            End If

            ' Done.
            Return args
        End Function

        ''' <summary>
        ''' Get the values for the arguments (if any).
        ''' </summary>
        ''' <param name="metadata">The ViewModel's metadata.</param>
        ''' <param name="navigationUri">The navigation URI.</param>
        ''' <returns></returns>
        <System.Runtime.CompilerServices.Extension()>
        Public Function GetArgumentValues(ByVal metadata As IViewModelMetadata,
                                          ByVal navigationUri As Uri) As NavigationArguments
            ' Dictionary holding the values.
            Dim values = New NavigationArguments()

            ' Process values.
            If navigationUri.OriginalString.Contains("/") Then
                ' Split the path to get the values.
                Dim split = navigationUri.OriginalString.Split(
                    New Char() {"/"c}, StringSplitOptions.RemoveEmptyEntries)

                ' Get the arguments from the metadata.
                Dim args = metadata.GetArguments()

                ' Add each value.
                For i = 1 To split.Length - 1
                    If args.Count >= i Then
                        values.Add(args(i - 1), split(i))
                    End If
                Next i
            End If

            ' Done.
            Return values
        End Function
	End Module
End Namespace
