﻿Namespace Utils.Silverlight.MVVM.Navigation
	Public Class NavigationArguments
		Inherits Dictionary(Of String, String)
		''' <summary>
		''' Get argument as integer.
		''' </summary>
		''' <param name="key"></param>
		''' <returns></returns>
		Public Function GetInt(ByVal key As String) As Integer?
			Return GetValue(Of Integer?)(key, Function(v) Convert.ToInt32(v))
		End Function

		''' <summary>
		''' Get argument as datetime.
		''' </summary>
		''' <param name="key"></param>
		''' <returns></returns>
		Public Function GetDateTime(ByVal key As String) As Date?
			Return GetValue(Of Date?)(key, Function(v) Date.Parse(v))
		End Function

		''' <summary>
		''' Get argument as guid.
		''' </summary>
		''' <param name="key"></param>
		''' <returns></returns>
		Public Function GetGuid(ByVal key As String) As Guid?
			Return GetValue(Of Guid?)(key, Function(v) New Guid(v))
		End Function

		''' <summary>
		''' Get argument as string.
		''' </summary>
		''' <param name="key"></param>
		''' <returns></returns>
		Public Function GetString(ByVal key As String) As String
			Return GetValue(Of String)(key, Function(v) v)
		End Function

		''' <summary>
		''' Helper method to get typed argument.
		''' </summary>
		''' <typeparam name="T"></typeparam>
		''' <param name="key"></param>
		''' <param name="convertFunc"></param>
		''' <returns></returns>
		Private Function GetValue(Of T)(ByVal key As String, ByVal convertFunc As Func(Of String, T)) As T
			' Get the default value for this type.
			Dim value As T = Nothing

			' Try to find the matching key and get its value if possible.
			Dim keyResult = Keys.FirstOrDefault(Function(o) o.Equals(key, StringComparison.OrdinalIgnoreCase))
			If keyResult IsNot Nothing Then
				value = convertFunc(Me(keyResult))
			End If

			' Done.
			Return value
		End Function
	End Class
End Namespace
